@@ -4,13 +4,14 @@
 
 #include <stdio.h>
 #include <string.h>
+#include "getopt.h"
 
 char	*optarg;	/* Global argument pointer. */
 int	optind77 = 0;	/* Global argv index. */
 
 static char	*scan = NULL;	/* Private scan pointer. */
 
-int our_getopt(int argc, char **argv, char *optstring)
+int our_getopt(int argc, char **argv, const char *optstring)
 {
 	register char c;
 	register char *place;
