@@ -575,7 +575,7 @@ void getdef(char *token, int toksiz, char *defn, int defsiz, FILE *fd)
 	 * define name defn
 	 *
 	 */
-	if ((t = gtok(ptoken, MAXTOK, fd)) != LPAREN) {;
+	if ((t = gtok(ptoken, MAXTOK, fd)) != LPAREN) {
 		t = BLANK;              /* define name defn */
 		pbstr(ptoken);
 	}
@@ -1550,6 +1550,81 @@ void retcod(void)
 	xfer = YES;
 }
 
+/*
+ * eosdef - return whether eos parameter is defined
+ *
+ */
+int eosdef(void)
+{
+        char eosdfn[MAXDEF];
+	if (look("eos",eosdfn) == YES)
+		return YES;
+	else if (look("EOS",eosdfn) == YES)
+		return YES;
+	else
+		return NO;
+}
+
+#define SBUFSZ 10000
+char savbuf[SBUFSZ];
+int savlen = 0;
+
+void savstr(const char *s)
+{
+	int i, size = SBUFSZ;
+	int slen = strlen(s);
+	int to_copy = size - savlen - 1;
+	if (slen + 1 > (size - savlen))
+		baderr("buffered string data too long.");
+	for (i = 0; i < slen; ++i)
+		savbuf[savlen+i] = s[i];
+	savlen += strlen(s);
+}
+
+void saveos(void)
+{
+        char eosdfn[MAXDEF];
+	if (look("eos",eosdfn) == YES) {
+		savstr(eosdfn);
+	} else if (look("EOS",eosdfn) == YES) {
+		savstr(eosdfn);
+	} else {
+		savstr("eos");
+	}
+}
+
+void savch(int ch)
+{
+        char foo[2] = {ch, '\0'};
+	savstr(foo);
+}
+
+void savnum(int num)
+{
+        char foo[11];
+	sprintf(foo,"%d",num);
+	savstr(foo);
+}
+
+void outsav(void)
+{
+	int i;
+	int tabbed = 0;
+        for (i = 0; i < savlen; ++i) {
+	        if (savbuf[i] == '\n') {
+		        outdon();
+			tabbed = 0;
+		} else {
+		        if (!tabbed) {
+			        outtab();
+				tabbed = 1;
+			}
+			outch(savbuf[i]);
+		}
+	}
+	savlen = 0;
+}
+
 /*
  * strdcl - generate code for string declaration
  *
@@ -1610,7 +1685,7 @@ void strdcl(void)
 	outch(RPAREN);
 	outdon();
 	outtab();
-	outstr(dat);
+	savstr(dat);
 	if (quoted) {
 		init[actlen] = EOS; /* delete the ending quote */
 		scopy(init, 1, init, 0); /* delete the starting quote */
@@ -1623,20 +1698,47 @@ void strdcl(void)
 		init[len-1] = EOS; /* truncate string to user-specified size */
 	}
 	for (i = 1; i <= len; i++) {	/* put out variable names */
-		outstr(name);
-		outch(LPAREN);
-		outnum(i);
-		outch(RPAREN);
+		savstr(name);
+		savch(LPAREN);
+		savnum(i);
+		savch(RPAREN);
 		if (i < len)
-			outch(COMMA);
+			savch(COMMA);
 		else
-			outch(SLASH);
+			savch(SLASH);
 	}
 	for (i = 0; init[i] != EOS; i++) {	/* put out init */
-		outnum(init[i]);
-		outch(COMMA);
+		savnum(init[i]);
+		savch(COMMA);
 	}
-	pbstr(eoss);	/* push back EOS for subsequent substitution */
+	if (eosdef() == NO)   /* EOS undefined */
+		synerr("warning: string directive used when EOS undefined.");
+	saveos();
+	savch(SLASH);
+	savch('\n');
+	/* Peek ahead to see whether we should emit the data statements now.
+	 * We don't do it yet if the next token is LEXSTRING or 
+	 * if the next two tokens are SEMICOL LEXSTRING. 
+	 * This is to avoid emitting code for a series of string declarations
+	 * all in a row which would trip over a pedantic error raised by f2c,
+	 * which insists that all variable declarations must come before any
+	 * other statements, including data statements. */
+	i = lex(init);
+	if (i != LEXSTRING) {
+		char temp[MAXTOK];
+		if (i == SEMICOL) {
+			i = lex(temp);
+			if (i != LEXSTRING) {
+				outsav();
+				outdon();
+			}
+			pbstr(temp);
+		} else {
+			outsav();
+			outdon();
+		}
+	}
+	pbstr(init);
 }
 
 /*
